@@ -58,7 +58,7 @@ void Audio::registerEngine(Engine *engine)
 	this->engine = engine;
 }
 
-bool Audio::loadSound(int i, char *filename)
+bool Audio::loadSound(int i, const char *filename)
 {
 	if (!engine->useAudio)
 	{
@@ -93,7 +93,7 @@ bool Audio::loadSound(int i, char *filename)
 	return true;
 }
 
-bool Audio::loadMusic(char *filename)
+bool Audio::loadMusic(const char *filename)
 {
 	char tempPath[PATH_MAX];
 	
@@ -181,10 +181,6 @@ void Audio::playMusicOnce()
 
 bool Audio::loadGameOverMusic()
 {
-	#if DEMO
-		return true;
-	#endif
-	
 	char tempPath[PATH_MAX];
 	
 	sprintf(tempPath, "%smusic.mod", engine->userHomeDirectory);
