@@ -27,7 +27,7 @@ Cutscene::Cutscene()
 	waitTime = 0;
 }
 
-void Cutscene::appendText(char *line)
+void Cutscene::appendText(const char *line)
 {
 	sprintf(text, "%s %s", text, line);
 }
