@@ -28,6 +28,6 @@ class Cutscene : public GameObject {
 		
 	Cutscene();
 	~Cutscene();
-	void appendText(char *line);
+	void appendText(const char *line);
 	
 };
