@@ -28,7 +28,7 @@ class Data : public GameObject {
 		int target;
 		
 	Data();
-	void set(char *key, char *value, int current, int target);
+	void set(const char *key, const char *value, int current, int target);
 	bool isComplete();
 	void getCurrentTarget(int *current, int *target);
 
