@@ -26,15 +26,18 @@ Engine::Engine()
 	{
 		keyState[i] = 0;
 	}
+	
+	for (int i = 0 ; i < 32 ; i++)
+	{
+		joystickState[i] = 0;
+	}
 
 	joyX = joyY = 0;
-	joyNavAvail = 0;
 
 	mouseLeft = mouseRight = 0;
 	waitForButton = false;
 	waitForKey = false;
 	
-	joystick[0] = joystick[1] = NULL;
 	allowJoypad = true;
 
 	strcpy(lastKeyPressed, "");
@@ -119,10 +122,6 @@ void Engine::clearCheatVars()
 
 bool Engine::compareLastKeyInputs()
 {
-	#if DEMO
-		return false;
-	#endif
-	
 	if (strstr(lastKeyEvents, "lockandload"))
 	{
 		cheats = true;
@@ -132,228 +131,6 @@ bool Engine::compareLastKeyInputs()
 	return false;
 }
 
-bool Engine::loadJoystickConfig()
-{
-	char filename[PATH_MAX];
-	sprintf(filename, "%sjoystick.cfg", userHomeDirectory);
-	
-	debug(("Loading joystick config from %s\n", filename));
-	
-	FILE *fp = fopen(filename, "rb");
-	if (!fp)
-	{
-		return false;
-	}
-		
-	if (fread(&joypad, sizeof(Joystick), 1, fp) != 1)
-	{
-		fclose(fp);
-		return false;
-	}
-		
-	fclose(fp);
-	
-	return true;
-}
-
-bool Engine::saveJoystickConfig()
-{
-	char filename[PATH_MAX];
-	sprintf(filename, "%sjoystick.cfg", userHomeDirectory);
-	
-	debug(("Saving joystick config to %s\n", filename));
-	
-	FILE *fp = fopen(filename, "wb");
-	
-	if (!fp)
-	{
-		return false;
-	}
-		
-	fwrite(&joypad, sizeof(Joystick), 1, fp);
-		
-	fclose(fp);
-	
-	return true;
-}
-
-bool Engine::loadKeyConfig()
-{
-	char filename[PATH_MAX];
-	sprintf(filename, "%skeyboard.cfg", userHomeDirectory);
-	
-	debug(("Loading keyboard config from %s\n", filename));
-	
-	FILE *fp = fopen(filename, "rb");
-	
-	if (!fp)
-	{
-		return false;
-	}
-		
-	if (fread(&keyboard, sizeof(Keyboard), 1, fp) != 1)
-	{
-		fclose(fp);
-		return false;
-	}
-		
-	fclose(fp);
-	
-	return true;
-}
-
-bool Engine::saveKeyConfig()
-{
-	char filename[PATH_MAX];
-	sprintf(filename, "%skeyboard.cfg", userHomeDirectory);
-	
-	debug(("Saving keyboard config to %s\n", filename));
-	
-	FILE *fp = fopen(filename, "wb");
-	
-	if (!fp)
-	{
-		return false;
-	}
-		
-	fwrite(&keyboard, sizeof(keyboard), 1, fp);
-		
-	fclose(fp);
-	
-	return true;
-}
-
-void Engine::restoreKeyDefaults()
-{
-	keyboard.setDefaultKeys();
-}
-
-bool Engine::isKey(int key)
-{
-	switch (key)
-	{
-		case KEY_UP:
-			return keyState[keyboard.jump];
-			break;
-		case KEY_DOWN:
-			return keyState[keyboard.down];
-			break;
-		case KEY_LEFT:
-			return keyState[keyboard.left];
-			break;
-		case KEY_RIGHT:
-			return keyState[keyboard.right];
-			break;
-		case KEY_FIRE:
-			return keyState[keyboard.fire];
-			break;
-		case KEY_MAP:
-			return keyState[keyboard.map];
-			break;
-		case KEY_PAUSE:
-			return keyState[keyboard.pause];
-			break;
-		case KEY_JETPACK:
-			return keyState[keyboard.jetpack];
-			break;
-	}
-	
-	return false;
-}
-
-void Engine::clearKey(int key)
-{
-	switch (key)
-	{
-		case KEY_UP:
-			keyState[keyboard.jump] = 0;
-			break;
-		case KEY_DOWN:
-			keyState[keyboard.down] = 0;
-			break;
-		case KEY_LEFT:
-			keyState[keyboard.left] = 0;
-			break;
-		case KEY_RIGHT:
-			keyState[keyboard.right] = 0;
-			break;
-		case KEY_FIRE:
-			keyState[keyboard.fire] = 0;
-			break;
-		case KEY_MAP:
-			keyState[keyboard.map] = 0;
-			break;
-		case KEY_PAUSE:
-			keyState[keyboard.pause] = 0;
-			break;
-		case KEY_JETPACK:
-			keyState[keyboard.jetpack] = 0;
-			break;
-	}
-}
-
-#define JOY_FLAKINESS 8
-
-bool Engine::getJoyLeft()
-{
-	if (SDL_GetTicks() < joyNavAvail)
-	{
-		return false;
-	}
-	
-	return (joyX / JOY_FLAKINESS) < 0;
-}
-
-bool Engine::getJoyRight()
-{
-	if (SDL_GetTicks() < joyNavAvail)
-	{
-		return false;
-	}
-	
-	return (joyX / JOY_FLAKINESS) > 0;
-}
-
-bool Engine::getJoyUp()
-{
-	if (SDL_GetTicks() < joyNavAvail)
-	{
-		return false;
-	}
-	
-	return (joyY / JOY_FLAKINESS) < 0;
-}
-
-bool Engine::getJoyDown()
-{
-	if (SDL_GetTicks() < joyNavAvail)
-	{
-		return false;
-	}
-	
-	return (joyY / JOY_FLAKINESS) > 0;
-}
-
-int Engine::getJoyX(int max)
-{
-  return int((double(joyX) / 32768.0) * double(max));
-}
-
-int Engine::getJoyY(int max)
-{
-  return int((double(joyY) / 32768.0) * double(max));
-}
-
-void Engine::lockJoy(Uint32 ticks)
-{
-	Uint32 newAvail = SDL_GetTicks() + ticks;
-
-	if (newAvail > joyNavAvail)
-	{
-		joyNavAvail = newAvail;
-	}
-}
-
 void Engine::addKeyEvent()
 {
 	if (strlen(lastKeyPressed) > 1)
@@ -425,6 +202,15 @@ void Engine::getInput()
 						allowJoypad = false;
 					}
 					
+					if (event.key.keysym.sym == SDLK_BACKSPACE)
+					{
+						lastButtonPressed = -2;
+						*highlightedWidget->value = -2;
+						highlightedWidget->redraw();
+						waitForButton = false;
+						allowJoypad = false;
+					}
+					
 					return;
 				}
 				
@@ -460,15 +246,17 @@ void Engine::getInput()
 			case SDL_JOYAXISMOTION:
 				if (event.jaxis.axis == 0)
 				{
-				  joyX=event.jaxis.value;
+				  joyX = event.jaxis.value;
 				}
 				else if (event.jaxis.axis == 1)
 				{
-				  joyY=event.jaxis.value;
+				  joyY = event.jaxis.value;
 				}
+				
 				break;
 
 			case SDL_JOYBUTTONDOWN:
+			
 				if (waitForButton)
 				{
 					lastButtonPressed = event.jbutton.button;
@@ -479,29 +267,11 @@ void Engine::getInput()
 					return;
 				}
 				
-				if (event.jbutton.button == joypad.fire)
-					keyState[keyboard.fire] = 1;
-				else if (event.jbutton.button == joypad.jump)
-					keyState[keyboard.jump] = 1;
-				else if (event.jbutton.button == joypad.jetpack)
-					keyState[keyboard.jetpack] = 1;
-				else if (event.jbutton.button == joypad.map)
-					keyState[keyboard.map] = 1;
-				else if (event.jbutton.button == joypad.pause)
-					keyState[keyboard.pause] = 1;
+				joystickState[event.jbutton.button] = 1;
 				break;
 
 			case SDL_JOYBUTTONUP:
-				if (event.jbutton.button == joypad.fire)
-					keyState[keyboard.fire] = 0;
-				else if (event.jbutton.button == joypad.jump)
-					keyState[keyboard.jump] = 0;
-				else if (event.jbutton.button == joypad.jetpack)
-					keyState[keyboard.jetpack] = 0;
-				else if (event.jbutton.button == joypad.map)
-					keyState[keyboard.map] = 0;
-				else if (event.jbutton.button == joypad.pause)
-					keyState[keyboard.pause] = 0;
+				joystickState[event.jbutton.button] = 0;
 				break;
 
 			default:
@@ -535,27 +305,6 @@ bool Engine::userAccepts()
 	return false;
 }
 
-void Engine::doPause()
-{
-	if (!paused)
-	{
-		if (keyState[keyboard.pause])
-		{
-			paused = true;
-			keyState[keyboard.pause] = 0;
-		}
-	}
-	else
-	{
-		if ((keyState[keyboard.pause]) || (keyState[SDLK_ESCAPE]))
-		{
-			paused = false;
-			keyState[keyboard.pause] = 0;
-			keyState[SDLK_ESCAPE] = 0;
-		}
-	}
-}
-
 void Engine::flushInput()
 {
 	while (SDL_PollEvent(&event)){}
@@ -569,7 +318,7 @@ void Engine::clearInput()
 	mouseLeft = mouseRight = 0;
 }
 
-void Engine::setUserHome(char *path)
+void Engine::setUserHome(const char *path)
 {
 	strcpy(userHomeDirectory, path);
 	debug(("User Home = %s\n", path));
@@ -586,7 +335,7 @@ it is found, the data is read into a character buffer.
 In the case of music, the data music be written to a temporary directory
 since SDL currently provides no means to load music directly from memory
 */
-bool Engine::unpack(char *filename, int fileType)
+bool Engine::unpack(const char *filename, int fileType)
 {
 	if (fileType == PAK_DATA)
 	{
@@ -660,7 +409,7 @@ bool Engine::unpack(char *filename, int fileType)
 	return true;
 }
 
-bool Engine::loadData(char *filename)
+bool Engine::loadData(const char *filename)
 {
 	if (dataBuffer != NULL)
 	{
@@ -741,7 +490,7 @@ void Engine::resetTimeDifference()
 	time1 = time2 = SDL_GetTicks();
 }
 
-void Engine::setInfoMessage(char *message, int priority, int type)
+void Engine::setInfoMessage(const char *message, int priority, int type)
 {
 	if (priority >= messagePriority)
 	{
@@ -770,7 +519,7 @@ void Engine::addWidget(Widget *widget)
 	widgetList.add(widget);
 }
 
-bool Engine::loadWidgets(char *filename)
+bool Engine::loadWidgets(const char *filename)
 {
 	deleteWidgets();
 
@@ -824,7 +573,7 @@ bool Engine::loadWidgets(char *filename)
 	return true;
 }
 
-Widget *Engine::getWidgetByName(char *name)
+Widget *Engine::getWidgetByName(const char *name)
 {
 	Widget *widget = (Widget*)widgetList.getHead();
 
@@ -841,7 +590,7 @@ Widget *Engine::getWidgetByName(char *name)
 	return NULL;
 }
 
-void Engine::showWidgetGroup(char *groupName, bool show)
+void Engine::showWidgetGroup(const char *groupName, bool show)
 {
 	bool found = false;
 
@@ -863,7 +612,7 @@ void Engine::showWidgetGroup(char *groupName, bool show)
 		debug(("Group '%s' does not exist\n", groupName));
 }
 
-void Engine::enableWidgetGroup(char *groupName, bool show)
+void Engine::enableWidgetGroup(const char *groupName, bool show)
 {
 	bool found = false;
 
@@ -885,7 +634,7 @@ void Engine::enableWidgetGroup(char *groupName, bool show)
 		debug(("Group '%s' does not exist\n", groupName));
 }
 
-void Engine::showWidget(char *name, bool show)
+void Engine::showWidget(const char *name, bool show)
 {
 	Widget *widget = getWidgetByName(name);
 	if (widget != NULL)
@@ -895,7 +644,7 @@ void Engine::showWidget(char *name, bool show)
 	}
 }
 
-void Engine::enableWidget(char *name, bool enable)
+void Engine::enableWidget(const char *name, bool enable)
 {
 	Widget *widget = getWidgetByName(name);
 	if (widget != NULL)
@@ -905,14 +654,14 @@ void Engine::enableWidget(char *name, bool enable)
 	}
 }
 
-void Engine::setWidgetVariable(char *name, int *variable)
+void Engine::setWidgetVariable(const char *name, int *variable)
 {
 	Widget *widget = getWidgetByName(name);
 	if (widget != NULL)
 		widget->value = variable;
 }
 
-bool Engine::widgetChanged(char *name)
+bool Engine::widgetChanged(const char *name)
 {
 	Widget *widget = getWidgetByName(name);
 	if (widget != NULL)
@@ -970,7 +719,7 @@ void Engine::highlightWidget(int dir)
 	highlightedWidget->redraw();
 }
 
-void Engine::highlightWidget(char *name)
+void Engine::highlightWidget(const char *name)
 {
 	highlightedWidget = getWidgetByName(name);
 }
@@ -979,34 +728,21 @@ int Engine::processWidgets()
 {
 	int update = 0;
 
-	if (keyState[SDLK_UP] || getJoyUp())
+	if (keyState[SDLK_UP])
 	{
 		highlightWidget(-1);
 		update = 1;
 		clearInput();
-
-		// Hack because there's no central event loop.  Without this,
-		// joystick navigation is impossible.
-		lockJoy(300);
 	}
 
-	if (keyState[SDLK_DOWN] || getJoyDown())
+	if (keyState[SDLK_DOWN])
 	{
 		highlightWidget(1);
 		update = 1;
 		clearInput();
-
-		// Hack because there's no central event loop.  Without this,
-		// joystick navigation is impossible.
-		lockJoy(300);
 	}
 
-	if (keyState[SDLK_LEFT] ||
-	    // Allow manipulation of everything but pushbuttons using
-	    // joypad-left.
-	    (highlightedWidget->type != WG_BUTTON &&
-	     highlightedWidget->type != WG_JOYPAD &&
-	     getJoyLeft()))
+	if (keyState[SDLK_LEFT] && (highlightedWidget->type != WG_BUTTON && highlightedWidget->type != WG_JOYPAD))
 	{
 		SDL_Delay(1);
 
@@ -1021,18 +757,9 @@ int Engine::processWidgets()
 
 		if ((highlightedWidget->type == WG_RADIO) || (highlightedWidget->type == WG_SLIDER))
 			clearInput();
-
-		// Hack because there's no central event loop.  Without this,
-		// joystick navigation is impossible.
-		lockJoy(300);
 	}
 
-	if (keyState[SDLK_RIGHT] ||
-	    // Allow manipulation of everything but pushbuttons using
-	    // joypad-right.
-	    (highlightedWidget->type != WG_BUTTON &&
-	     highlightedWidget->type != WG_JOYPAD &&
-	     getJoyRight()))
+	if (keyState[SDLK_RIGHT] && (highlightedWidget->type != WG_BUTTON && highlightedWidget->type != WG_JOYPAD))
 	{
 		SDL_Delay(1);
 
@@ -1047,10 +774,6 @@ int Engine::processWidgets()
 
 		if ((highlightedWidget->type == WG_RADIO) || (highlightedWidget->type == WG_SLIDER))
 			clearInput();
-
-		// Hack because there's no central event loop.  Without this,
-		// joystick navigation is impossible.
-		lockJoy(300);
 	}
 
 	if ((keyState[SDLK_RETURN]) || (keyState[SDLK_SPACE]) || (keyState[SDLK_LCTRL]))
@@ -1091,10 +814,6 @@ int Engine::processWidgets()
 
 		flushInput();
 		clearInput();
-
-		// Hack because there's no central event loop.  Without this,
-		// joystick navigation is impossible.
-		lockJoy(300);
 	}
 
 	return update;
@@ -1179,7 +898,7 @@ traverse the list and return 1 when it encounters ACTIVE. This has two advantage
 the code, I don't have to change all the data entries too. You probably already
 thought of that though... :)
 */
-int Engine::getValueOfDefine(char *word)
+int Engine::getValueOfDefine(const char *word)
 {
 	int rtn = 0;
 
@@ -1203,7 +922,7 @@ int Engine::getValueOfDefine(char *word)
 /*
 Does the opposite of the above(!)
 */
-char *Engine::getDefineOfValue(char *prefix, int value)
+char *Engine::getDefineOfValue(const char *prefix, int value)
 {
 	int rtn = 0;
 
@@ -1234,7 +953,7 @@ the function above, delimited with plus signs. So ENT_FLIES+ENT_AIMS. It then wo
 flags (in a bit of a half arsed manner because of my lazy (2 << 25) declarations, adds all
 the values together and then returns them... phew! Makes data files human readable though :)
 */
-int Engine::getValueOfFlagTokens(char *realLine)
+int Engine::getValueOfFlagTokens(const char *realLine)
 {
 	if (strcmp(realLine, "0") == 0)
 		return 0;
