@@ -40,17 +40,6 @@ class Engine {
 		
 		Pak pak;
 
-		// Consolidate joystick axis information.
-		int joyX, joyY;
-
-		// Used to temporarily disable the joystick (eg, in
-		// option screens): the tick at which joystick
-		// navigation will be re-enabled.
-		//
-		// Note: may break if the game runs for more than
-		// 49 days, resulting in an inoperable joystick.
-		Uint32 joyNavAvail;
-
 	public:
 		
 		int extremeAvailable;
@@ -58,16 +47,11 @@ class Engine {
 		char keyState[350];
 		char mouseLeft, mouseRight;
 		
-		SDL_Joystick *joystick[2];
-		Joystick joypad;
-		
-		Keyboard keyboard;
+		int joyX, joyY;
+		int joystickState[32]; // hopefully no one has a joystick with this many buttons(!)
 		bool waitForButton;
 		bool waitForKey;
 		bool allowJoypad;
-		
-		bool isKey(int key);
-		void clearKey(int key);
 
 		bool paused;
 		bool saveConfig;
@@ -116,39 +100,18 @@ class Engine {
 	int getMouseX();
 	int getMouseY();
 
-	bool getJoyLeft();
-	bool getJoyRight();
-	bool getJoyUp();
-	bool getJoyDown();
-
-	// Return a value between -max and +max.
-	int getJoyX(int max);
-	int getJoyY(int max);
-	void lockJoy(Uint32 ticks);
-
 	void setMouse(int x, int y);
 	bool userAccepts();
 	
-	bool loadJoystickConfig();
-	bool saveJoystickConfig();
-	
-	bool loadKeyConfig();
-	bool saveKeyConfig();
-	void restoreKeyDefaults();
-	
-	bool getKeyState(int key);
-	void setKeyState(int key);
-	
-	void doPause();
 	void clearCheatVars();
 	bool compareLastKeyInputs();
 	void addKeyEvent();
 	void flushInput();
 	void clearInput();
-	void setUserHome(char *path);
+	void setUserHome(const char *path);
 	Pak *getPak();
-	bool unpack(char *filename, int fileType);
-	bool loadData(char *filename);
+	bool unpack(const char *filename, int fileType);
+	bool loadData(const char *filename);
 	void reportFontFailure();
 	void setPlayerPosition(int x, int y, int limitLeft, int limitRight, int limitUp, int limitDown);
 	int getFrameLoop();
@@ -156,23 +119,23 @@ class Engine {
 	void doTimeDifference();
 	float getTimeDifference();
 	void resetTimeDifference();
-	void setInfoMessage(char *message, int priority, int type);
+	void setInfoMessage(const char *message, int priority, int type);
 	void deleteWidgets();
 	void addWidget(Widget *widget);
-	bool loadWidgets(char *filename);
-	Widget *getWidgetByName(char *name);
-	void showWidgetGroup(char *groupName, bool show);
-	void enableWidgetGroup(char *groupName, bool show);
-	void showWidget(char *name, bool show);
-	void enableWidget(char *name, bool enable);
-	void setWidgetVariable(char *name, int *variable);
-	bool widgetChanged(char *name);
+	bool loadWidgets(const char *filename);
+	Widget *getWidgetByName(const char *name);
+	void showWidgetGroup(const char *groupName, bool show);
+	void enableWidgetGroup(const char *groupName, bool show);
+	void showWidget(const char *name, bool show);
+	void enableWidget(const char *name, bool enable);
+	void setWidgetVariable(const char *name, int *variable);
+	bool widgetChanged(const char *name);
 	void highlightWidget(int dir);
-	void highlightWidget(char *name);
+	void highlightWidget(const char *name);
 	int processWidgets();
 	bool loadDefines();
-	int getValueOfDefine(char *word);
-	char *getDefineOfValue(char *prefix, int value);
-	int getValueOfFlagTokens(char *line);
+	int getValueOfDefine(const char *word);
+	char *getDefineOfValue(const char *prefix, int value);
+	int getValueOfFlagTokens(const char *line);
 	void delay(unsigned int frameLimit);
 };
