@@ -28,15 +28,15 @@ FileData::FileData()
 	location = 0;
 }
 
-void FileData::set(char *filename, Uint32 fSize, Uint32 cSize, Uint32 location)
+void FileData::set(const char *filename, Uint32 fSize, Uint32 cSize, Uint32 location)
 {
 	if (strlen(filename) > 59)
 	{
 		printf("WARNING: FileData::set - FILENAME EXCEEDS 60 CHARACTERS!!!\n");
+		return;
 	}
 	
-	strncpy(this->filename, filename, 59);
-	filename[59] = '\0';
+	strcpy(this->filename, filename);
 	
 	this->fSize = fSize;
 	this->cSize = cSize;
