@@ -29,5 +29,5 @@ class FileData {
 
 	FileData();
 	
-	void set(char *filename, Uint32 fSize, Uint32 cSize, Uint32 location);
+	void set(const char *filename, Uint32 fSize, Uint32 cSize, Uint32 location);
 };
