@@ -468,17 +468,19 @@ void Graphics::loadMapTiles(const char *baseDir)
 		if (found)
 		{
 			tile[i] = loadImage(filename);
-			
-			if (i < MAP_DECORATION)
-			{
-				SDL_SetColorKey(tile[i], 0, 0);
-			}
 
 			if (autoAlpha)
 			{
 				if ((i < MAP_EXITSIGN) || (i >= MAP_WATERANIM))
 				{
-					SDL_SetAlpha(tile[i], SDL_SRCALPHA|SDL_RLEACCEL, 128);
+					SDL_SetAlpha(tile[i], SDL_SRCALPHA|SDL_RLEACCEL, 130);
+				}
+			}
+			else
+			{
+				if (i < MAP_DECORATION)
+				{
+					SDL_SetColorKey(tile[i], 0, SDL_MapRGB(tile[i]->format, 0, 0, 0));
 				}
 			}
 		}
@@ -931,23 +933,8 @@ void Graphics::drawWidgetRect(int x, int y, int w, int h)
 SDL_Surface *Graphics::createSurface(int width, int height)
 {
 	SDL_Surface *surface, *newImage;
-	Uint32 rmask, gmask, bmask, amask;
 
-	/* SDL interprets each pixel as a 32-bit number, so our masks must depend
-	on the endianness (byte order) of the machine */
-	#if (SDL_BYTEORDER == SDL_BIG_ENDIAN)
-		rmask = 0xff000000;
-		gmask = 0x00ff0000;
-		bmask = 0x0000ff00;
-		amask = 0x000000ff;
-	#else
-		rmask = 0x000000ff;
-		gmask = 0x0000ff00;
-		bmask = 0x00ff0000;
-		amask = 0xff000000;
-	#endif
-
-	surface = SDL_CreateRGBSurface(SDL_SWSURFACE, width, height, 32, rmask, gmask, bmask, amask);
+	surface = SDL_CreateRGBSurface(SDL_SWSURFACE, width, height, screen->format->BitsPerPixel, screen->format->Rmask, screen->format->Gmask, screen->format->Bmask, screen->format->Amask);
 
 	if (surface == NULL)
 		showErrorAndExit("CreateRGBSurface failed: %s\n", SDL_GetError());
@@ -965,7 +952,7 @@ SDL_Surface *Graphics::alphaRect(int width, int height, Uint8 red, Uint8 green,
 
 	SDL_FillRect(surface, NULL, SDL_MapRGB(surface->format, red, green, blue));
 
-	SDL_SetAlpha(surface, SDL_SRCALPHA|SDL_RLEACCEL, 128);
+	SDL_SetAlpha(surface, SDL_SRCALPHA|SDL_RLEACCEL, 130);
 
 	return surface;
 }
