@@ -22,15 +22,10 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 Joystick::Joystick()
 {
-	numberOfButtons = 0;
+	sensitivity = 25000;
 
-	left = 0;
-	right = 1;
-	up = 2;
-	down = 3;
-	fire = 4;
-	jump = 5;
-	jetpack = 6;
-	pause = 7;
-	map = 8;
+	for (int i = 0 ; i < CONTROL::MAX ; i++)
+	{
+		control[i] = i;
+	}
 }
