@@ -31,7 +31,7 @@ LineDef::LineDef()
 	next = NULL;
 }
 
-void LineDef::set(char *name, char *linkName, char *activateMessage, int x, int y, int width, int height)
+void LineDef::set(const char *name, const char *linkName, const char *activateMessage, int x, int y, int width, int height)
 {
 	strcpy(this->name, name);
 	strcpy(this->linkName, linkName);
