@@ -30,6 +30,6 @@ class LineDef : public GameObject {
 		bool activated;
 
 	LineDef();
-	void set(char *name, char *linkName, char *activateMessage, int x, int y, int width, int height);
+	void set(const char *name, const char *linkName, const char *activateMessage, int x, int y, int width, int height);
 
 };
