@@ -96,28 +96,28 @@ class Map {
 	bool isLiquid(int x, int y);
 	bool isTopLayer(int x, int y);
 	
-	Persistant *getPersistant(char *name);
-	Persistant *createPersistant(char *name);
-	void destroyPersistant(char *name);
+	Persistant *getPersistant(const char *name);
+	Persistant *createPersistant(const char *name);
+	void destroyPersistant(const char *name);
 	
-	void setName(char *name);
+	void setName(const char *name);
 	void setClipping(int limitLeft, int limitRight, int limitUp, int limitDown);
-	void addTrain(char *name, int startX, int startY, int endX, int endY, int pause, bool atStart, bool active);
-	void addDoor(char *name, int type, int startX, int startY, int endX, int endY, bool active);
-	void addSwitch(char *name, char *linkName, char *requiredObjectName, char *activateMessage, int type, int x, int y, bool activated);
+	void addTrain(const char *name, int startX, int startY, int endX, int endY, int pause, bool atStart, bool active);
+	void addDoor(const char *name, int type, int startX, int startY, int endX, int endY, bool active);
+	void addSwitch(const char *name, const char *linkName, const char *requiredObjectName, const char *activateMessage, int type, int x, int y, bool activated);
 	void addItem(Entity *item);
 	void addBullet(Entity *bullet);
 	void addParticle(float x, float y, float dx, float dy, int health, int color, Sprite *sprite, int flags);
 	void addEnemy(Entity *enemy);
 	void addMIA(Entity *mia);
 	void addObstacle(Entity *obstacle);
-	void addSpawnPoint(char *name, int x, int y, int type, int subtype, int min, int max, bool active);
+	void addSpawnPoint(const char *name, int x, int y, int type, int subtype, int min, int max, bool active);
 	void addEffect(Effect *effect);
-	void addObjective(char *description, char *target, int targetValue, bool required);
+	void addObjective(const char *description, const char *target, int targetValue, bool required);
 	void addTeleporter(Teleporter *teleporter);
 	void addLineDef(LineDef *lineDef);
 	void addTrap(Trap *trap);
-	void evalTileset(char *baseDir);
+	void evalTileset(const char *baseDir);
 	
 	void killAllEnemies();
 	
