@@ -76,15 +76,25 @@ void Math::wrapFloat(float *in, float low, float high)
 		*in = low;
 }
 
-int Math::prand()
+long Math::prand()
 {
-	pSeed = pSeed * 7654321 + 12345;
-	pSeed = (unsigned int)(pSeed / 65536) % 32768;
-
+	long k1;
+	long ix = pSeed;
+	
+	k1 = ix / 127773;
+	ix = 16807 * (ix - k1 * 127773) - k1 * 2836;
+	
+	if (ix < 0)
+	{
+		ix += 2147483647;
+	}
+	
+	pSeed = ix;
+	
 	return pSeed;
 }
 
-int Math::rrand(int min, int max)
+long Math::rrand(int min, int max)
 {
 	int r = min;
 
@@ -141,4 +151,4 @@ char *Math::formatTime(int t)
 	return time;
 }
 
-unsigned int Math::pSeed;
+long Math::pSeed;
