@@ -32,7 +32,7 @@ Objective::Objective()
 	next = NULL;
 }
 
-Objective::Objective(char *description, char *target, int targetValue, bool required)
+Objective::Objective(const char *description, const char *target, int targetValue, bool required)
 {
 	strcpy(this->description, description);
 	strcpy(this->target, target);
