@@ -19,7 +19,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 #include "headers.h"
-#include "SDL/SDL_endian.h"
 
 Pak::Pak()
 {
@@ -59,7 +58,7 @@ void Pak::showPakErrorAndExit()
 	exit(1);
 }
 
-void Pak::setPakFile(char *pakFilename)
+void Pak::setPakFile(const char *pakFilename)
 {
 	#if USEPAK
 	strcpy(this->pakFilename, pakFilename);
@@ -77,9 +76,6 @@ void Pak::setPakFile(char *pakFilename)
 	fread(&listPos, sizeof(Uint32), 1, pak);
 	fread(&numberOfFiles, sizeof(Uint32), 1, pak);
 	
-	listPos = SDL_SwapLE32(listPos);
-	numberOfFiles = SDL_SwapLE32(numberOfFiles);
-	
 	debug(("Pak : File list resides at %d\n", (int)listPos));
 	debug(("Pak : Number of files are %d\n", (int)numberOfFiles));
 	
@@ -100,8 +96,6 @@ void Pak::setPakFile(char *pakFilename)
 		}
 		
 		debug(("Read FileData #%d / %d : %s\n", (i + 1), numberOfFiles, fd[i].filename));
-		
-		fd[i].swapEndians();
 	}
 	
 	fclose(pak);
@@ -109,7 +103,7 @@ void Pak::setPakFile(char *pakFilename)
 	#endif
 }
 
-bool Pak::unpack(char *filename, unsigned char **buffer)
+bool Pak::unpack(const char *filename, unsigned char **buffer)
 {
 	debug(("Pak : Unpacking %s...\n", filename));
 	
@@ -166,7 +160,7 @@ bool Pak::unpack(char *filename, unsigned char **buffer)
 	return true;
 }
 
-bool Pak::fileExists(char *filename)
+bool Pak::fileExists(const char *filename)
 {
 	unsigned int hashcode = 0;
 	unsigned int length = strlen(filename);
