@@ -29,7 +29,7 @@ PersistData::~PersistData()
 {
 }
 
-bool PersistData::setData(char *data)
+bool PersistData::setData(const char *data)
 {
 	if (strlen(data) > 149)
 	{
