@@ -32,7 +32,7 @@ Persistant::~Persistant()
 	numberOfLines = 0;
 }
 
-void Persistant::setName(char *name)
+void Persistant::setName(const char *name)
 {
 	strcpy(this->stageName, name);
 }
@@ -43,7 +43,7 @@ void Persistant::clear()
 	numberOfLines = 0;
 }
 
-void Persistant::addLine(char *data)
+void Persistant::addLine(const char *data)
 {
 	PersistData *persistant = new PersistData();
 	
