@@ -34,7 +34,7 @@ class SpawnPoint : public GameObject {
 
 	SpawnPoint();
 	void reset();
-	void create(char *name, int x, int y, int spawnType, int spawnSubType, int minInterval, int maxInterval, bool active);
+	void create(const char *name, int x, int y, int spawnType, int spawnSubType, int minInterval, int maxInterval, bool active);
 	void think();
 	bool readyToSpawn();
 
