@@ -35,7 +35,7 @@ Switch::Switch()
 	next = NULL;
 }
 
-void Switch::set(char *name, char *linkName, char *requiredObjectName, char *activateMessage, int type, int x, int y, bool activated)
+void Switch::set(const char *name, const char *linkName, const char *requiredObjectName, const char *activateMessage, int type, int x, int y, bool activated)
 {
 	strcpy(this->name, name);
 	strcpy(this->linkName, linkName);
