@@ -33,6 +33,6 @@ class Switch : public GameObject {
 		bool activated;
 
 		Switch();
-		void set(char *name, char *linkName, char *requiredObjectName, char *activateMessage, int type, int x, int y, bool activated);
+		void set(const char *name, const char *linkName, const char *requiredObjectName, const char *activateMessage, int type, int x, int y, bool activated);
 		
 };
