@@ -27,7 +27,7 @@ Teleporter::Teleporter()
 	sprite = NULL;
 }
 
-void Teleporter::setName(char *name)
+void Teleporter::setName(const char *name)
 {
 	strcpy(this->name, name);
 }
