@@ -31,7 +31,7 @@ class Teleporter : public GameObject {
 		int destX, destY;
 
 	Teleporter();
-	void setName(char *name);
+	void setName(const char *name);
 	void set(int x, int y, int destX, int destY);
 	void setActive(bool active);
 
