@@ -50,7 +50,7 @@ class Train : public GameObject {
 	bool isReady();
 	bool isMoving();
 	bool waitsForPlayer();
-	void setName(char *name);
+	void setName(const char *name);
 	void set(int startX, int startY, int endX, int endY, int pause, bool fromStart);
 	bool openClose();
 	void move();
