@@ -36,7 +36,7 @@ class Trap : public GameObject {
 		Sprite *sprite;
 
 	Trap();
-	void setName(char *name);
+	void setName(const char *name);
 	void setTrapType(int trapType);
 	void setSprite(Sprite *sprite);
 	void setSpeed(int speed);
