@@ -29,7 +29,7 @@ class Weapon {
 		Sprite *sprite[2];
 
 	Weapon();
-	void setName(char *name);
+	void setName(const char *name);
 	int getSpeed(int face);
 
 };
