@@ -39,7 +39,7 @@ class Widget : public GameObject {
 		Widget *previous;
 
 	Widget();
-	void setProperties(char *name, char *groupName, char *label, char *options, int x, int y, int min, int max);
+	void setProperties(const char *name, const char *groupName, const char *label, const char *options, int x, int y, int min, int max);
 	void setValue(int *value);
 	void redraw();
 
