@@ -20,16 +20,16 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "headers.h"
 
-extern void addItem(int itemType, char *name, int x, int y, char *spriteName, int health, int value, int flags, bool randomMovement);
+extern void addItem(int itemType, const char *name, int x, int y, const char *spriteName, int health, int value, int flags, bool randomMovement);
 extern void addTeleportParticles(float x, float y, int amount, int soundToPlay);
 extern void addColorParticles(float x, float y, int amount, int color);
-extern bool okayToSpawnEnemy(char *name, int x, int y);
-extern void addEnemy(char *name, int x, int y, int flags);
+extern bool okayToSpawnEnemy(const char *name, int x, int y);
+extern void addEnemy(const char *name, int x, int y, int flags);
 extern void moveEntity(Entity *entity);
 extern void addFireTrailParticle(float x, float y);
-extern void checkObjectives(char *name, bool alwaysInform);
+extern void checkObjectives(const char *name, bool alwaysInform);
 
-extern Entity *getEnemy(char *name);
+extern Entity *getEnemy(const char *name);
 extern Weapon *getRandomAimedWeapon();
 extern Weapon *getRandomStraightWeapon();
 extern Weapon *getRandomGaldovWeapon();
