@@ -20,7 +20,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "enemies.h"
 
-Entity *getDefinedEnemy(char *name)
+Entity *getDefinedEnemy(const char *name)
 {
 	for (int i = 0 ; i < MAX_ENEMIES ; i++)
 	{
@@ -35,7 +35,7 @@ Entity *getDefinedEnemy(char *name)
 	return NULL;
 }
 
-Entity *getEnemy(char *name)
+Entity *getEnemy(const char *name)
 {
 	Entity *enemy = (Entity*)map.enemyList.getHead();
 
@@ -54,7 +54,7 @@ Entity *getEnemy(char *name)
 	return NULL;
 }
 
-void addEnemy(char *name, int x, int y, int flags)
+void addEnemy(const char *name, int x, int y, int flags)
 {
 	Entity *enemy = new Entity();
 	Entity *defEnemy = getDefinedEnemy(name);
@@ -153,7 +153,7 @@ void lookForPlayer(Entity *enemy)
 		enemy->owner->tx = (int)(player.x);
 		enemy->owner->ty = (int)(player.y);
 	}
-	else if ((rand() % (35 - game.skill)) == 0)
+	else if ((Math::prand() % (35 - game.skill)) == 0)
 	{
 		enemy->owner->tx = (int)(player.x);
 		enemy->owner->ty = (int)(player.y);
@@ -182,7 +182,7 @@ void lookForPlayer(Entity *enemy)
 				addBullet(enemy, enemy->currentWeapon->getSpeed(enemy->face), -2);
 			}
 		}
-		else if ((rand() % 850) <= (game.skill * 5))
+		else if ((Math::prand() % 850) <= (game.skill * 5))
 		{
 			addBullet(enemy, enemy->currentWeapon->getSpeed(enemy->face), 0);
 			if (enemy->currentWeapon == &weapon[WP_ALIENSPREAD])
@@ -196,12 +196,12 @@ void lookForPlayer(Entity *enemy)
 		{
 			if (enemy->flags & ENT_ALWAYSFIRES)
 			{
-				if ((rand() % 25) > game.skill * 3)
+				if ((Math::prand() % 25) > game.skill * 3)
 					Math::removeBit(&enemy->flags, ENT_ALWAYSFIRES);
 			}
 			else
 			{
-				if ((rand() % 50) < game.skill * 2)
+				if ((Math::prand() % 50) < game.skill * 2)
 					Math::addBit(&enemy->flags, ENT_ALWAYSFIRES);
 			}
 		}
@@ -219,7 +219,7 @@ void lookForPlayer(Entity *enemy)
 	{
 		if (!enemy->falling)
 		{
-			if ((rand() % 25) == 0)
+			if ((Math::prand() % 25) == 0)
 			{
 				int distance = Math::rrand(1, 4);
 				enemy->setVelocity(distance - ((distance * 2) * enemy->face), Math::rrand(-12, -10));
@@ -234,7 +234,7 @@ void lookForPlayer(Entity *enemy)
 	{
 		if (!enemy->falling)
 		{
-			if ((rand() % 100) == 0)
+			if ((Math::prand() % 100) == 0)
 			{
 				enemy->dy = -12;
 			}
@@ -280,7 +280,7 @@ void doAI(Entity *enemy)
 
 	if ((int)enemy->x == enemy->tx)
 	{
-		if ((rand() % 100) == 0)
+		if ((Math::prand() % 100) == 0)
 		{
 			enemy->tx = (int)(enemy->x + Math::rrand(-640, 640));
 			enemy->ty = (int)(enemy->y);
@@ -459,11 +459,11 @@ void enemyBulletCollisions(Entity *bullet)
 							
 							if (enemy->flags & ENT_EXPLODES)
 							{
-								audio.playSound(SND_ELECDEATH1 + rand() % 3, CH_DEATH);
+								audio.playSound(SND_ELECDEATH1 + Math::prand() % 3, CH_DEATH);
 							}
 							else if (game.gore)
 							{
-								audio.playSound(SND_DEATH1 + rand() % 3, CH_DEATH);
+								audio.playSound(SND_DEATH1 + Math::prand() % 3, CH_DEATH);
 							}
 						}
 					}
@@ -478,16 +478,16 @@ void enemyBulletCollisions(Entity *bullet)
 				if (enemy->health < 0)
 				{
 					enemy->dx = Math::rrand(-3, 3);
-					enemy->dy = 5 - rand() % 15;
+					enemy->dy = 5 - Math::prand() % 15;
 					enemy->health = -1;
 					
 					if (enemy->flags & ENT_EXPLODES)
 					{
-						audio.playSound(SND_ELECDEATH1 + rand() % 3, CH_DEATH);
+						audio.playSound(SND_ELECDEATH1 + Math::prand() % 3, CH_DEATH);
 					}
 					else if (game.gore)
 					{
-						audio.playSound(SND_DEATH1 + rand() % 3, CH_DEATH);
+						audio.playSound(SND_DEATH1 + Math::prand() % 3, CH_DEATH);
 					}
 
 					if (bullet->owner == &player)
@@ -513,7 +513,7 @@ void enemyBulletCollisions(Entity *bullet)
 	}
 }
 
-int getNonGoreParticleColor(char *name)
+int getNonGoreParticleColor(const char *name)
 {
 	int rtn = graphics.yellow;
 	
@@ -712,7 +712,7 @@ void doEnemies()
 				Math::removeBit(&enemy->flags, ENT_FLIES);
 				Math::addBit(&enemy->flags, ENT_INANIMATE);
 				Math::addBit(&enemy->flags, ENT_BOUNCES);
-				enemy->health = -1 - rand() % 25;
+				enemy->health = -1 - Math::prand() % 25;
 			}
 			
 			if (engine.cheatBlood)
@@ -727,7 +727,7 @@ void doEnemies()
 					{
 						if (game.gore)
 						{
-							audio.playSound(SND_DEATH1 + rand() % 3, CH_DEATH);
+							audio.playSound(SND_DEATH1 + Math::prand() % 3, CH_DEATH);
 						}
 					}
 				}
@@ -741,7 +741,7 @@ void doEnemies()
 				{
 					if ((enemy->health % 3) == 0)
 					{
-						addExplosion(enemy->x + rand() % 25, enemy->y + rand() % 25,  10 + (20 * game.skill), enemy);
+						addExplosion(enemy->x + Math::prand() % 25, enemy->y + Math::prand() % 25,  10 + (20 * game.skill), enemy);
 						addSmokeAndFire(enemy, Math::rrand(-5, 5), Math::rrand(-5, 5), 2);
 					}
 				}
@@ -805,7 +805,7 @@ void doEnemies()
 	}
 }
 
-void loadEnemy(char *token)
+void loadEnemy(const char *token)
 {
 	int enemy = -1;
 
