@@ -61,7 +61,7 @@ void throwAndDamageEntity(Entity *ent, int damage, int minDX, int maxDX, int DY)
 
 		if (player.health <= 0)
 		{
-			audio.playSound(SND_DEATH1 + rand() % 3, CH_DEATH);
+			audio.playSound(SND_DEATH1 + Math::prand() % 3, CH_DEATH);
 			player.health = 0;
 		}
 
@@ -74,7 +74,7 @@ void throwAndDamageEntity(Entity *ent, int damage, int minDX, int maxDX, int DY)
 		ent->health -= damage;
 	}
 
-	((rand() % 2) == 0) ? ent->dx = -minDX : ent->dx = maxDX;
+	((Math::prand() % 2) == 0) ? ent->dx = -minDX : ent->dx = maxDX;
 	
 	if (ent->dy >= 0)
 	{
@@ -247,7 +247,7 @@ void moveEntity(Entity *ent)
 		int diffY = (abs((int)ent->y - (int)ent->dy) / 20);
 
 		// add teleport particles so we can see where thing are going (no sound)
-		addTeleportParticles(ent->x + rand() % ent->width, ent->y + rand() % ent->height, 3, -1);
+		addTeleportParticles(ent->x + Math::prand() % ent->width, ent->y + Math::prand() % ent->height, 3, -1);
 
 		Math::limitInt(&diffX, 3, 30);
 		Math::limitInt(&diffY, 3, 30);
@@ -312,7 +312,7 @@ void moveEntity(Entity *ent)
 			ent->applyGravity();
 		}
 		// This is what makes swimming work:
-		else if ((!engine.isKey(KEY_UP)) && (!engine.isKey(KEY_DOWN)) && (!engine.getJoyUp()) && (!engine.getJoyDown()))
+		else if ((!config.isControl(CONTROL::UP)) && (!config.isControl(CONTROL::JUMP))  && (!config.isControl(CONTROL::DOWN)))
 		{
 			ent->applyGravity();
 		}
