@@ -20,7 +20,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "headers.h"
 
-extern void checkObjectives(char *name, bool alwaysInform);
+extern void checkObjectives(const char *name, bool alwaysInform);
 extern void throwAndDamageEntity(Entity *ent, int damage, int minDX, int maxDX, int DY);
 extern void addSmokeAndFire(Entity *ent, float dx, float dy, int amount);
 extern void addBlood(Entity *ent, float dx, float dy, int amount);
