@@ -84,15 +84,6 @@ void showInGameOptions()
 	{
 		engine.showWidget("quit", false);
 	}
-	
-	#if DEMO
-		engine.enableWidget("escape", false);
-		engine.enableWidget("restart", false);
-		
-		Widget *widget;
-		widget = engine.getWidgetByName("quit");
-		strcpy(widget->label, "Quit Game");
-	#endif
 
 	engine.flushInput();
 	engine.clearInput();
@@ -106,11 +97,12 @@ void showInGameOptions()
 	{
 		graphics.updateScreen();		
 		engine.getInput();
+		config.populate();
 
-		if ((engine.isKey(KEY_PAUSE)) || (engine.keyState[SDLK_ESCAPE]))
+		if ((config.isControl(CONTROL::PAUSE)) || (engine.keyState[SDLK_ESCAPE]))
 		{
 			engine.keyState[SDLK_ESCAPE] = 0;
-			engine.clearKey(KEY_PAUSE);
+			config.resetControl(CONTROL::PAUSE);
 			break;
 		}
 		
@@ -223,11 +215,7 @@ void showInGameOptions()
 
 		if ((quityes) || (trainyes))
 		{
-			#if !DEMO
 			game.setMissionOver(MIS_PLAYERQUIT);
-			#else
-			showDemoEnd();
-			#endif
 			break;
 		}
 		
@@ -248,10 +236,12 @@ void showInGameOptions()
 void doGameStuff()
 {
 	engine.getInput();
+	config.populate();
+	replayData.read(config.command);
 	
 	if (game.missionOverReason == MIS_INPROGRESS)
 	{
-		engine.doPause();
+		config.doPause();
 	}
 
 	engine.doFrameLoop();
@@ -290,6 +280,9 @@ void doGameStuff()
 	{
 		engine.paused = true;
 	}
+	
+	replayData.set(config.command);	
+	replayData.commit();
 }
 
 int gameover()
@@ -304,10 +297,8 @@ int gameover()
 
 	SDL_Surface *gameover = graphics.quickSprite("Game Over", graphics.loadImage("gfx/main/gameover.png"));
 
-	#if !DEMO
 	audio.loadGameOverMusic();
 	audio.playMusic();
-	#endif
 
 	engine.flushInput();
 	engine.clearInput();
@@ -375,10 +366,6 @@ int gameover()
 		graphics.fadeToBlack();
 		map.clear();
 		
-		#if DEMO
-			showDemoEnd();
-		#endif
-		
 		return SECTION_TITLE;
 	}
 
@@ -420,8 +407,7 @@ void showMissionInformation()
 	if (map.totalMIAs > 0)
 	{
 		graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
-		sprintf(message, "%s", _("Rescue %d MIAs"));
-		sprintf(message, message, map.requiredMIAs);
+		sprintf(message, _("Rescue %d MIAs"), map.requiredMIAs);
 		graphics.drawString(message, col1, y, TXT_LEFT, panel);
 
 		if (map.foundMIAs < map.requiredMIAs)
@@ -599,7 +585,7 @@ int doGame()
 		player.health = -99;
 
 		//#if USEPAK
-		if (!map.isBossMission)
+		if ((!map.isBossMission) && (replayData.replayMode == REPLAY_MODE::NONE))
 		{
 			showMissionInformation();
 		}
@@ -682,7 +668,7 @@ int doGame()
 			}
 		}
 
-		if (engine.isKey(KEY_MAP))
+		if (config.isControl(CONTROL::MAP))
 		{
 			if (!map.isBossMission)
 			{
@@ -699,7 +685,14 @@ int doGame()
 
 		if ((engine.keyState[SDLK_ESCAPE]) && (game.missionOver == 0))
 		{
-			showInGameOptions();
+			if (replayData.replayMode == REPLAY_MODE::NONE)
+			{
+				showInGameOptions();
+			}
+			else
+			{
+				exit(0);
+			}
 		}
 
 		if (allObjectivesCompleted())
@@ -721,7 +714,9 @@ int doGame()
 
 		if (game.missionOver > 0)
 		{
-			if (SDL_GetTicks() > game.missionOver)
+			game.missionOver--;
+		
+			if (game.missionOver == 0)
 			{
 				if (game.missionOverReason == MIS_PLAYEROUT)
 				{
@@ -737,7 +732,7 @@ int doGame()
 				{
 					if (game.missionOverReason == MIS_COMPLETE)
 					{
-						game.missionOver = SDL_GetTicks() + 2000;
+						game.missionOver = MAX_FPS * 2;
 						
 						if (strcmp(map.name, "Space Station") != 0)
 						{
@@ -754,10 +749,15 @@ int doGame()
 					{
 						addTeleportParticles(player.x, player.y, 50, SND_TELEPORT3);
 						game.missionOverReason = MIS_PLAYERESCAPE;
-						game.missionOver = SDL_GetTicks() + 4000;
+						game.missionOver = MAX_FPS * 4;
 					}
 					else
 					{
+						if (replayData.replayMode != REPLAY_MODE::NONE)
+						{
+							exit(0);
+						}
+					
 						break;
 					}
 				}
@@ -769,8 +769,8 @@ int doGame()
 		if (millis >= 60)
 		{
 			millis = 0;
-
-			if (game.missionOverReason == MIS_INPROGRESS)
+			
+			if ((game.missionOverReason == MIS_INPROGRESS) || (game.missionOverReason == MIS_PLAYEROUT))
 			{
 				game.incrementMissionTime();
 				
@@ -790,7 +790,8 @@ int doGame()
 		while (engine.paused)
 		{
 			engine.getInput();
-			engine.doPause();
+			config.populate();
+			config.doPause();
 			graphics.updateScreen();
 			then = SDL_GetTicks();
 			frames = 0;
@@ -816,7 +817,21 @@ int doGame()
 		}		
 		#endif
 		
-		engine.delay(frameLimit);
+		if (replayData.replayMode != REPLAY_MODE::PLAYBACK)
+		{
+			engine.delay(frameLimit);
+		}
+		else if (!replayData.fast)
+		{
+			engine.delay(frameLimit);
+		}
+		
+		if (engine.keyState[SDLK_F5])
+		{
+			replayData.fast = !replayData.fast;
+			engine.keyState[SDLK_F5] = 0;
+		}
+		
 		frameLimit = SDL_GetTicks()  + 16;
 		
 		if (game.missionOverReason == MIS_GAMECOMPLETE)
@@ -861,10 +876,6 @@ int doGame()
 				
 				showMissionClear();
 				
-				#if DEMO
-				showDemoEnd();
-				#endif
-				
 				if (engine.practice)
 				{
 					return SECTION_TITLE;
