@@ -61,17 +61,18 @@ extern bool allObjectivesCompleted();
 extern void showMissionClear();
 extern void autoCompleteAllObjectives(bool allObjectives);
 extern void doCredits();
-extern void showDemoEnd();
 
 extern void checkEndCutscene();
 extern void processPostMissionData();
 extern void clearAllMissionData();
 extern void saveGame();
 
+extern Audio audio;
+extern Config config;
 extern Engine engine;
 extern Graphics graphics;
 extern Map map;
-extern Audio audio;
+extern ReplayData replayData;
 
 extern Entity player;
 extern Game game;
