@@ -92,3 +92,7 @@ extern DECLSPEC int SDLCALL SDL_GetGamma(float *red, float *green, float *blue);
 #include "CRadarBlip.h"
 
 #include "CCutscene.h"
+
+#include "CReplayDataHeader.h"
+#include "CReplayData.h"
+#include "CConfig.h"
