@@ -632,7 +632,7 @@ int doHub()
 			mouseYDelta = 5;
 		}
 		
-		if (config.isControl(CONTROL::UP))
+		if (config.isControl(CONTROL::UP) || config.isControl(CONTROL::JUMP))
 		{
 			mouseYDelta = -5;
 		}
