@@ -108,7 +108,7 @@ void doStatusBar()
 					graphics.blit(graphics.getSprite("WarningBlock", true)->getCurrentFrame(), 315 + (i * 15), 7, graphics.screen, false);
 	}
 
-	if ((map.mainBossPart == NULL) || (strstr(engine.message, "Aqua")) || (strstr(engine.message, "Jet")) && (game.missionOverReason != MIS_GAMECOMPLETE))
+	if ((map.mainBossPart == NULL || strstr(engine.message, "Aqua") || strstr(engine.message, "Jet")) && (game.missionOverReason != MIS_GAMECOMPLETE))
 	{
 		if (engine.messageTime > -1)
 		{
@@ -206,7 +206,7 @@ void doPauseInfo()
 	col2 = 330;
 	y = 60;
 
-	graphics.fade(128);
+	graphics.fade(130);
 
 	char string[1024];
 	strcpy(string, "");
