@@ -18,21 +18,21 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include <time.h>
-
 #if UNIX
 	#include <sys/stat.h>
 	#include <pwd.h>
 	#include <unistd.h>
 	#include <errno.h>
 #endif
-
+#include <time.h>
 #include "headers.h"
 
-extern SDL_Surface *loadImage(char *filename);
+extern SDL_Surface *loadImage(const char *filename);
 
 extern Audio audio;
+extern Config config;
 extern Engine engine;
 extern Game game;
 extern Graphics graphics;
 extern Map map;
+extern ReplayData replayData;
