@@ -24,8 +24,9 @@ extern void drawMapTopLayer();
 extern void loadResources();
 extern void doGameStuff();
 extern void doSpawnPoints();
-extern void addItem(int itemType, char *name, int x, int y, char *spriteName, int health, int value, int flags, bool randomMovement);
+extern void addItem(int itemType, const char *name, int x, int y, const char *spriteName, int health, int value, int flags, bool randomMovement);
 
+extern Config config;
 extern Engine engine;
 extern Graphics graphics;
 extern Map map;
