@@ -25,7 +25,7 @@ extern void drawMap(int offsetX, int offsetY);
 extern void cleanup();
 extern bool checkBrickContact(Entity *object);
 extern void moveEntity(Entity *ent);
-extern void checkObjectives(char *name, bool alwaysInform);
+extern void checkObjectives(const char *name, bool alwaysInform);
 extern void addTeleportParticles(float x, float y, int amount, int soundToPlay);
 
 extern Audio audio;
