@@ -20,7 +20,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "lineDefs.h"
 
-void addLineDef(char *name, char *linkName, char *message, int x, int y, int width, int height, bool active)
+void addLineDef(const char *name, const char *linkName, const char *message, int x, int y, int width, int height, bool active)
 {
 	LineDef *lineDef = new LineDef();
 
@@ -30,7 +30,7 @@ void addLineDef(char *name, char *linkName, char *message, int x, int y, int wid
 	map.addLineDef(lineDef);
 }
 
-void showMessageLineDef(char *linkName, bool show)
+void showMessageLineDef(const char *linkName, bool show)
 {
 	LineDef *lineDef = (LineDef*)map.lineList.getHead();
 
@@ -77,8 +77,8 @@ void doLineDefs()
 			{
 				if ((strcmp(lineDef->name, "Exit") == 0) && (!requiredObjectivesCompleted()))
 				{
-					engine.clearKey(KEY_LEFT);
-					engine.clearKey(KEY_RIGHT);
+					config.resetControl(CONTROL::LEFT);
+					config.resetControl(CONTROL::RIGHT);
 
 					if (player.dx > 0) player.x = (lineDef->x - player.width) - 2;
 					if (player.dx < 0) player.x = (lineDef->x + lineDef->width + 2);
