@@ -20,12 +20,13 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "headers.h"
 
-void checkObjectives(char *name, bool alwaysInform);
+void checkObjectives(const char *name, bool alwaysInform);
 extern bool requiredObjectivesCompleted();
-extern void activateTrigger(char *linkName, char *activateMessage, bool active);
+extern void activateTrigger(const char *linkName, const char *activateMessage, bool active);
 extern void stealCrystal();
 
 extern Audio audio;
+extern Config config;
 extern Engine engine;
 extern Game game;
 extern Graphics graphics;
