@@ -31,6 +31,16 @@ void showHelp()
 
 	printf("The Metal Blob Solid gameplay manual can be found in,\n");
 	printf("\t%s\n\n", GAMEPLAYMANUAL);
+	
+	printf("Replay Commands\n");
+	printf("\t-map <filename>       Play the specified map (use -listmaps to see maps)\n");
+	printf("\t-record <filename>    Record a game and output to the specified file\n");
+	printf("\t-playback <filename>  Playback the specified recording\n");
+	printf("\t-listmaps             List the available maps for playing\n\n");
+	
+	printf("Replay Examples\n");
+	printf("\tblobwars -map data/grasslands1 -record replay.dat\n");
+	printf("\tblobwars -playback replay.dat\n\n");
 
 	printf("Additional Commands\n");
 	printf("\t-fullscreen         Start the game in Full Screen mode\n");
@@ -42,6 +52,42 @@ void showHelp()
 	exit(0);
 }
 
+void listMaps()
+{
+	printf("\n");
+	printf("Blob Wars, Episode I - Metal Blob Solid (Version %.2f, Release %d)\n", VERSION, RELEASE);
+	printf("Copyright (C) 2004 Parallel Realities\n");
+	printf("Licensed under the GNU General Public License (GPL)\n\n");
+	
+	printf("Available Maps\n");
+	printf("\tdata/arcticWastes\n");
+	printf("\tdata/assimilator\n");
+	printf("\tdata/caves1\n");
+	printf("\tdata/caves2\n");
+	printf("\tdata/caves3\n");
+	printf("\tdata/caves4\n");
+	printf("\tdata/comm\n");
+	printf("\tdata/finalBattle\n");
+	printf("\tdata/floodedTunnel1\n");
+	printf("\tdata/floodedTunnel2\n");
+	printf("\tdata/floodedTunnel3\n");
+	printf("\tdata/floodedTunnel4\n");
+	printf("\tdata/grasslands1\n");
+	printf("\tdata/grasslands2\n");
+	printf("\tdata/grasslands3\n");
+	printf("\tdata/hq\n");
+	printf("\tdata/icecave1\n");
+	printf("\tdata/icecave2\n");
+	printf("\tdata/spaceStation\n");
+	printf("\tdata/supply\n");
+	printf("\tdata/tomb1\n");
+	printf("\tdata/tomb2\n");
+	printf("\tdata/tomb3\n");
+	printf("\tdata/tomb4\n\n");
+	
+	exit(0);
+}
+
 void showVersion()
 {
 	printf("\n");
@@ -56,6 +102,10 @@ int main(int argc, char *argv[])
 	#if !USEPAK
 	debug(("Not Using PAK...\n"));
 	#endif
+	
+	config.engine = &engine;
+	
+	replayData.reset();
 
 	bindtextdomain("blobwars", LOCALEDIR);
 	setlocale(LC_ALL, "");
@@ -63,9 +113,11 @@ int main(int argc, char *argv[])
 
 	atexit(cleanup);
 
-	int requiredSection = SECTION_INTRO;
 	bool showSprites = false;
 	bool hub = false;
+	
+	int recordMode = REPLAY_MODE::NONE;
+	int requiredSection = SECTION_INTRO;
 
 	for (int i = 1 ; i < argc ; i++)
 	{
@@ -74,10 +126,12 @@ int main(int argc, char *argv[])
 		else if (strcmp(argv[i], "-mono") == 0) engine.useAudio = 1;
 		else if (strcmp(argv[i], "-version") == 0) showVersion();
 		else if (strcmp(argv[i], "--help") == 0) showHelp();
+		else if (strcmp(argv[i], "-record") == 0) {recordMode = REPLAY_MODE::RECORD; strcpy(replayData.filename, argv[++i]);}
+		else if (strcmp(argv[i], "-playback") == 0) {recordMode = REPLAY_MODE::PLAYBACK; strcpy(replayData.filename, argv[++i]);}
+		else if (strcmp(argv[i], "-map") == 0) {game.setMapName(argv[++i]); requiredSection = SECTION_GAME;}
+		else if (strcmp(argv[i], "-listmaps") == 0) listMaps();
 		
 		#if !USEPAK
-		else if (strcmp(argv[i], "-map") == 0) {game.setMapName(argv[++i]); requiredSection = SECTION_GAME;}
-		else if (strcmp(argv[i], "-skill") == 0) game.skill = atoi(argv[++i]);
 		else if (strcmp(argv[i], "-showsprites") == 0) showSprites = true;
 		else if (strcmp(argv[i], "-hub") == 0) hub = true;
 		else if (strcmp(argv[i], "-randomscreens") == 0) graphics.takeRandomScreenShots = true;
@@ -86,14 +140,34 @@ int main(int argc, char *argv[])
 		#endif
 	}
 	
-	#if DEMO
-		game.setMapName("data/floodedTunnel1");
-		requiredSection = SECTION_GAME;
-		game.skill = 1;
-	#endif
+	switch (recordMode)
+	{
+		case REPLAY_MODE::NONE:
+			// nothing to do...
+			break;
+			
+		case REPLAY_MODE::RECORD:
+			requiredSection = SECTION_GAME;
+			strcpy(replayData.header.map, game.mapName);
+			replayData.header.skill = game.skill = 3;
+			replayData.setMode(REPLAY_MODE::RECORD);
+			break;
+			
+		case REPLAY_MODE::PLAYBACK:
+			requiredSection = SECTION_GAME;
+			replayData.setMode(REPLAY_MODE::PLAYBACK);
+			replayData.header.time = 0;
+			game.setMapName(replayData.header.map);
+			game.skill = replayData.header.skill;
+			break;
+	}
 
 	initSystem();
-
+	
+	// seed the random using the one generated
+	// via the replay data
+	Math::pSeed = replayData.header.randomSeed;
+	
 	player.setName("Player");
 
 	engine.flushInput();
@@ -136,9 +210,6 @@ int main(int argc, char *argv[])
 			case SECTION_GAME:
 				if (!game.continueFromCheckPoint)
 				{
-					#if DEMO
-						showDemoStart();
-					#endif
 					checkStartCutscene();
 					loadResources();
 				}
