@@ -45,11 +45,13 @@ extern void checkStartCutscene();
 extern void easyGameFinished();
 
 Audio audio;
+Config config;
 Engine engine;
 Game game;
 GameData gameData;
 Graphics graphics;
 Map map;
+ReplayData replayData;
 
 Entity defEnemy[MAX_ENEMIES];
 Entity defItem[MAX_ITEMS];
