@@ -20,7 +20,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "headers.h"
 
-extern bool requiredEnemy(char *name);
+extern bool requiredEnemy(const char *name);
 extern void addBubble(float x, float y);
 extern void adjustObjectives();
 extern void initMIAPhrases();
@@ -28,6 +28,7 @@ extern void addWindParticles();
 extern void getMapTokens();
 
 extern Audio audio;
+extern Config config;
 extern Engine engine;
 extern Game game;
 extern Graphics graphics;
