@@ -64,6 +64,7 @@ void showMap(int *mapX, int *mapY)
 	{
 		graphics.updateScreen();
 		engine.getInput();
+		config.populate();
 
 		if (engine.keyState[SDLK_SPACE])
 			break;
@@ -202,7 +203,7 @@ void deleteEnemy(int x, int y)
 	}
 }
 
-void saveMap(char *name)
+void saveMap(const char *name)
 {
 	FILE *fp = fopen(name, "wb");
 	Entity *enemy = (Entity*)map.enemyList.getHead();
@@ -274,7 +275,7 @@ void collectMapData()
 			{
 				for (int y = 0 ; y < MAPHEIGHT ; y++)
 				{
-					if ((map.data[x][y] >= 9) && (map.data[x][y] <= 20) && ((rand() % 2) == 0))
+					if ((map.data[x][y] >= 9) && (map.data[x][y] <= 20) && ((Math::prand() % 2) == 0))
 						map.data[x][y] = Math::rrand(9, 20);
 				}
 			}
@@ -296,7 +297,7 @@ void collectMapData()
 	fclose(fp);
 }
 
-void newMap(char *name)
+void newMap(const char *name)
 {
 	FILE *fp = fopen(name, "wb");
 
@@ -341,7 +342,7 @@ void addTileDecoration()
 		{
 			if ((map.data[x][y] == 9) && (map.data[x][y - 1] == MAP_AIR))
 			{
-				if (rand() % 4)
+				if (Math::prand() % 4)
 					map.data[x][y - 1] = 241;
 			}
 		}
@@ -353,7 +354,7 @@ void addTileDecoration()
 		{
 			if (map.data[x][y] == 241)
 			{
-				if ((rand() % 3) == 0)
+				if ((Math::prand() % 3) == 0)
 					map.data[x][y] = 242;
 			}
 		}
@@ -467,6 +468,7 @@ int main(int argc, char *argv[])
 	while (true)
 	{
 		engine.getInput();
+		config.populate();
 		engine.doPause();
 		engine.doFrameLoop();
 
