@@ -31,7 +31,7 @@ void initMIAPhrases()
 	strcpy(mia_scared[6], "i don't like it here...");
 }
 
-void addMIA(char *name, int x, int y, int type)
+void addMIA(const char *name, int x, int y, int type)
 {
 	Entity *mia = new Entity();
 
@@ -88,12 +88,12 @@ void doMIAs()
 
 				if (mia->value < 100)
 				{
-					if ((rand() % 250) == 0)
+					if ((Math::prand() % 250) == 0)
 						mia->value = 100;
 				}
 				else
 				{
-					if ((rand() % 250) == 0)
+					if ((Math::prand() % 250) == 0)
 						mia->value = Math::rrand(0, 6);
 				}
 
@@ -128,7 +128,7 @@ void doMIAs()
 			if (mia->flags & ENT_DYING)
 			{
 				for (int i = 0 ; i < 2 ; i++)
-					map.addParticle(mia->x + Math::rrand(-2, 15), mia->y + rand() % mia->height, 0, Math::rrand(-5, -1), Math::rrand(30, 60), graphics.red, graphics.getSprite("TeleportStar", true), PAR_WEIGHTLESS);
+					map.addParticle(mia->x + Math::rrand(-2, 15), mia->y + Math::prand() % mia->height, 0, Math::rrand(-5, -1), Math::rrand(30, 60), graphics.red, graphics.getSprite("TeleportStar", true), PAR_WEIGHTLESS);
 
 				if (mia->health <= 100)
 					mia->y -= 5;
