@@ -173,7 +173,7 @@ void showMissionClear()
 	int col2 = 380;
 	int count = 0;
 	int place = 0;
-	int nextStarBurst = 10 * (rand() % 6);
+	int nextStarBurst = 10 * (Math::prand() % 6);
 
 	float px, py, dx, dy;
 
@@ -220,8 +220,7 @@ void showMissionClear()
 	if (map.totalMIAs > 0)
 	{
 		graphics.setFontColor(0xff, 0xff, 0xff, 0x00, 0x00, 0x00);
-		sprintf(message, "%s", _("Rescue %d MIAs"));
-		sprintf(message, message, map.requiredMIAs);
+		sprintf(message, _("Rescue %d MIAs"), map.requiredMIAs);
 		graphics.drawString(message, col1, y, TXT_RIGHT, graphics.background);
 
 		if (map.foundMIAs < map.requiredMIAs)
@@ -289,6 +288,7 @@ void showMissionClear()
 	while (true)
 	{
 		engine.getInput();
+		config.populate();
 		graphics.updateScreen();
 		graphics.animateSprites();
 
@@ -337,7 +337,7 @@ void showMissionClear()
 
 				if (nextStarBurst == 0)
 				{
-					nextStarBurst = 10 * (rand() % 6);
+					nextStarBurst = 10 * (Math::prand() % 6);
 
 					px = Math::rrand(50, 585);
 					py = Math::rrand(55, 85);
@@ -363,13 +363,11 @@ void showMissionClear()
 
 	audio.stopMusic();
 
-	#if !DEMO	
 	processPostMissionData();
 
 	if (!engine.practice)
 	{
 		saveGame();
 	}
-	#endif
 }
 
