@@ -140,7 +140,7 @@ bool perfectlyCompleted()
 	return true;
 }
 
-bool requiredEnemy(char *name)
+bool requiredEnemy(const char *name)
 {
 	Objective *objective = (Objective*)map.objectiveList.getHead();
 
@@ -237,7 +237,7 @@ void autoCompleteAllObjectives(bool allObjectives)
 	}
 }
 
-void checkObjectives(char *name, bool alwaysInform)
+void checkObjectives(const char *name, bool alwaysInform)
 {
 	Objective *objective = (Objective*)map.objectiveList.getHead();
 
@@ -298,7 +298,7 @@ void checkObjectives(char *name, bool alwaysInform)
 				{
 					if ((requiredValue % 10 == 0) || (requiredValue <= 10) || (alwaysInform))
 					{
-						switch (rand() % 3)
+						switch (Math::prand() % 3)
 						{
 							case 0:
 								sprintf(message, _("%s - %d more to go..."), _(objective->description), requiredValue);
