@@ -64,6 +64,7 @@ void showCheatConfig()
 			audio.playMenuSound(menuSound);
 
 		engine.getInput();
+		config.populate();
 
 		menuSound = engine.processWidgets();
 
@@ -114,15 +115,15 @@ void showKeyConfig()
 	int done = 0;
 	int defaults = 0;
 
-	engine.setWidgetVariable("left", &engine.keyboard.left);
-	engine.setWidgetVariable("right", &engine.keyboard.right);
-	engine.setWidgetVariable("down", &engine.keyboard.down);
-	engine.setWidgetVariable("fire", &engine.keyboard.fire);
-	engine.setWidgetVariable("jump", &engine.keyboard.jump);
-	engine.setWidgetVariable("pause", &engine.keyboard.pause);
+	engine.setWidgetVariable("left", &config.keyboard.control[CONTROL::LEFT]);
+	engine.setWidgetVariable("right", &config.keyboard.control[CONTROL::RIGHT]);
+	engine.setWidgetVariable("down", &config.keyboard.control[CONTROL::DOWN]);
+	engine.setWidgetVariable("fire", &config.keyboard.control[CONTROL::FIRE]);
+	engine.setWidgetVariable("jump", &config.keyboard.control[CONTROL::JUMP]);
+	engine.setWidgetVariable("pause", &config.keyboard.control[CONTROL::PAUSE]);
 
-	engine.setWidgetVariable("jetpack", &engine.keyboard.jetpack);
-	engine.setWidgetVariable("map", &engine.keyboard.map);
+	engine.setWidgetVariable("jetpack", &config.keyboard.control[CONTROL::JETPACK]);
+	engine.setWidgetVariable("map", &config.keyboard.control[CONTROL::MAP]);
 
 	engine.setWidgetVariable("defaults", &defaults);
 	engine.setWidgetVariable("confirm", &done);
@@ -148,6 +149,7 @@ void showKeyConfig()
 		}
 
 		engine.getInput();
+		config.populate();
 
 		menuSound = engine.processWidgets();
 
@@ -157,7 +159,7 @@ void showKeyConfig()
 		
 		if (defaults)
 		{
-			engine.restoreKeyDefaults();
+			config.restoreKeyDefaults();
 			defaults = 0;
 		}
 
@@ -173,7 +175,7 @@ void showKeyConfig()
 	
 	engine.allowJoypad = true;
 	
-	engine.saveKeyConfig();
+	config.saveKeyConfig();
 
 	audio.playMenuSound(2);
 
@@ -201,17 +203,20 @@ void showJoystickConfig()
 	SDL_SetColorKey(optionsBackground, 0, SDL_MapRGB(optionsBackground->format, 0, 0, 0));
 
 	int done = 0;
+	int sensitivity = (config.joystick.sensitivity / 100);
 
-	engine.setWidgetVariable("left", &engine.joypad.left);
-	engine.setWidgetVariable("right", &engine.joypad.right);
-	engine.setWidgetVariable("up", &engine.joypad.up);
-	engine.setWidgetVariable("down", &engine.joypad.down);
-	engine.setWidgetVariable("fire", &engine.joypad.fire);
-	engine.setWidgetVariable("jump", &engine.joypad.jump);
-	engine.setWidgetVariable("pause", &engine.joypad.pause);
+	engine.setWidgetVariable("left", &config.joystick.control[CONTROL::LEFT]);
+	engine.setWidgetVariable("right", &config.joystick.control[CONTROL::RIGHT]);
+	engine.setWidgetVariable("up", &config.joystick.control[CONTROL::UP]);
+	engine.setWidgetVariable("down", &config.joystick.control[CONTROL::DOWN]);
+	engine.setWidgetVariable("fire", &config.joystick.control[CONTROL::FIRE]);
+	engine.setWidgetVariable("jump", &config.joystick.control[CONTROL::JUMP]);
+	engine.setWidgetVariable("pause", &config.joystick.control[CONTROL::PAUSE]);
 
-	engine.setWidgetVariable("jetpack", &engine.joypad.jetpack);
-	engine.setWidgetVariable("map", &engine.joypad.map);
+	engine.setWidgetVariable("jetpack", &config.joystick.control[CONTROL::JETPACK]);
+	engine.setWidgetVariable("map", &config.joystick.control[CONTROL::MAP]);
+	
+	engine.setWidgetVariable("sensitivity", &sensitivity);
 
 	engine.setWidgetVariable("confirm", &done);
 	
@@ -234,6 +239,7 @@ void showJoystickConfig()
 			audio.playMenuSound(menuSound);
 
 		engine.getInput();
+		config.populate();
 
 		menuSound = engine.processWidgets();
 
@@ -251,9 +257,11 @@ void showJoystickConfig()
 		SDL_Delay(16);
 	}
 	
+	config.joystick.sensitivity = (sensitivity * 100);
+	
 	engine.allowJoypad = true;
 	
-	engine.saveJoystickConfig();
+	config.saveJoystickConfig();
 
 	audio.playMenuSound(2);
 
@@ -332,6 +340,7 @@ void showOptions()
 			audio.playMenuSound(menuSound);
 
 		engine.getInput();
+		config.populate();
 
 		if (engine.compareLastKeyInputs())
 		{
