@@ -18,11 +18,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 */
 
-#include "zlib.h"
-#include "SDL/SDL_endian.h"
-#include "CFileData.h"
-
 #include <dirent.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
+
+#include "headers.h"
