@@ -20,7 +20,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #include "resources.h"
 
-void loadSound(int index, char *filename)
+void loadSound(int index, const char *filename)
 {
 	if (!audio.loadSound(index, filename))
 		graphics.showErrorAndExit(ERR_FILE, filename);
@@ -28,7 +28,7 @@ void loadSound(int index, char *filename)
 	graphics.showLoading(1, 30);
 }
 
-void loadSprite(char *token)
+void loadSprite(const char *token)
 {
 	Sprite *sprite;
 
@@ -66,9 +66,7 @@ void loadResources()
 	audio.free();
 	graphics.free();
 	
-	#if !DEMO
 	graphics.quickSprite("cheatHeader", graphics.loadImage("gfx/main/cheats.png"));
-	#endif
 	graphics.quickSprite("optionsHeader", graphics.loadImage("gfx/main/options.png"));
 	graphics.quickSprite("joystickHeader", graphics.loadImage("gfx/main/joystickConfig.png"));
 	graphics.quickSprite("keyHeader", graphics.loadImage("gfx/main/keyConfig.png"));
