@@ -24,9 +24,9 @@ extern void loadDefEnemies();
 extern void loadDefWeapons();
 extern void loadDefItems();
 
-extern bool loadMapData(char *filename);
+extern bool loadMapData(const char *filename);
 
-extern void createBoss(char *stageName);
+extern void createBoss(const char *stageName);
 
 extern Audio audio;
 extern Engine engine;
