@@ -21,8 +21,8 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "headers.h"
 
 extern void addBullet(Entity *owner, float dx, float dy);
-extern void addEnemy(char *name, int x, int y, int flags);
-extern Entity *getDefinedEnemy(char *name);
+extern void addEnemy(const char *name, int x, int y, int flags);
+extern Entity *getDefinedEnemy(const char *name);
 extern void addTeleportParticles(float x, float y, int amount, int soundToPlay);
 extern void addExplosion(float x, float y, int radius, Entity *owner);
 extern void dropHelperItems(int x, int y);
