@@ -21,7 +21,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include "headers.h"
 
 extern void evaluateMapAttribute(Entity *ent, int mapAttribute);
-extern bool carryingItem(char *name);
+extern bool carryingItem(const char *name);
 
 extern Audio audio;
 extern Engine engine;
