@@ -22,7 +22,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 extern void toggleTrap(Trap *trap);
 extern void addTeleportParticles(float x, float y, int amount, int soundToPlay);
-extern void showMessageLineDef(char *linkName, bool show);
+extern void showMessageLineDef(const char *linkName, bool show);
 
 extern Audio audio;
 extern Engine engine;
